@@ -41,25 +41,39 @@
 #define QBS_SETUPQT_H
 
 #include <tools/error.h>
-#include <QCoreApplication>
-#include <QStringList>
+#include <tools/version.h>
+
+#include <QtCore/qcoreapplication.h>
+#include <QtCore/qstringlist.h>
+
+#include <vector>
 
 namespace qbs {
-class QtEnvironment;
+
 class Settings;
 
+class QtEnvironment
+{
+public:
+    QString qmakeFilePath;
+    QStringList qbsToolchain;
+    QString architecture;
+    QString targetPlatform;
+    Version qtVersion;
+    Version msvcVersion;
+};
+
 class SetupQt
 {
     Q_DECLARE_TR_FUNCTIONS(SetupQt)
 public:
     static bool isQMakePathValid(const QString &qmakePath);
-    static QList<QtEnvironment> fetchEnvironments();
-    static void addQtBuildVariant(QtEnvironment *env, const QString &buildVariantName);
+    static std::vector<QtEnvironment> fetchEnvironments();
     static QtEnvironment fetchEnvironment(const QString &qmakePath);
-    static void saveToQbsSettings(const QString &qtVersionName, const QtEnvironment & qtEnvironment,
+    static bool checkIfMoreThanOneQtWithTheSameVersion(const Version &qtVersion,
+                                                       const std::vector<QtEnvironment> &qtEnvironments);
+    static void saveToQbsSettings(const QString &qtVersionName, const QtEnvironment &qtEnvironment,
                                   Settings *settings);
-    static bool checkIfMoreThanOneQtWithTheSameVersion(const QString &qtVersion,
-            const QList<QtEnvironment> &qtEnvironments);
 };
 
 } // namespace qbs
